#import "SUFeedDownload.h"
#import "SUUpdateDownload.h"

@class SUUpdateWindowController;

typedef enum {
	SUSoftwareUpdateStateIdle,
	SUSoftwareUpdateStateDownloadingFeed,
	SUSoftwareUpdateStateParsingFeed,
	SUSoftwareUpdateStateDisplayingUpdateAvailableUI,
	SUSoftwareUpdateStateDownloadingUpdate
} SUSoftwareUpdateState;

@interface SUSoftwareUpdate : NSObject<SUFeedDownloadDelegate, SUUpdateDownloadDelegate> {
@private
	id _delegate;
	BOOL _hasPerformedStartupActions;
	SUSoftwareUpdateState _softwareUpdateState;
	BOOL _isManualCheck;
	SUFeedDownload *_feedDownload;
	SUUpdateDownload *_updateDownload;
	SUUpdateWindowController *_updateWindowController;
}

+ (id)sharedSoftwareUpdater;

- (id)delegate;
- (void)setDelegate:(id)delegate;

/* Should only be called by Carbon applications for manual initialization */
- (void)performStartupActions;

/* Should be called by the application delegate's -applicationShouldTerminate: method. */
- (BOOL)shouldTerminate; 

- (NSURL *)feedURL;
- (NSString *)userAgent;
- (NSString *)helpAnchor;

/* Can we install an update without authorization? */
- (BOOL)canInstallUpdate; 

- (BOOL)canCheckForUpdates; /* KVO compliant */
- (IBAction)checkForUpdates:(id)sender;

- (BOOL)openSoftwareUpdatePreferences;

@end

@interface NSObject(SUSoftwareUpdateDelegate)

- (void)openSoftwareUpdatePreferences:(SUSoftwareUpdate *)softwareUpdater;
- (void)getQuitEventClass:(AEEventClass *)eventClass eventID:(AEEventID *)eventID;

@end

/* User defaults keys */
extern NSString * const SUSoftwareUpdateEnabled; /* BOOL value */
extern NSString * const SUSoftwareUpdateCheckInterval; /* Integer value; unit is days */
